Index: trunk/psModules/test/objects/tap_pmPeaks.c
===================================================================
--- trunk/psModules/test/objects/tap_pmPeaks.c	(revision 29547)
+++ trunk/psModules/test/objects/tap_pmPeaks.c	(revision 31153)
@@ -650,95 +650,3 @@
     ok(test_pmPeaksInImage(TST02_NUM_ROWS, 2*TST02_NUM_COLS),
       "Tested pmPeaksInImage() on (%d, %d) image", TST02_NUM_ROWS, 2*TST02_NUM_COLS);
-
-
-    // ------------------------------------------------------------------------
-    // Test pmPeaksSubset()
-    // Calling pmPeaksSubset with NULL psList.  Should generate error.
-    {
-        psMemId id = psMemGetId();
-        psArray *outData = pmPeaksSubset(NULL, 0.0, psRegionSet(0, 0, 0, 0));
-        ok(outData == NULL, "pmPeaksSubset() returned a NULL with a NULL psArray input");
-        psFree(outData);
-        ok(!psMemCheckLeaks (id, NULL, NULL, false), "no memory leaks");
-    }
-
-
-    // Set peaks in input image.  All even-column and even-row pixels are
-    // set non-zero, all other pixels are set to zero.
-    psImage *imgData = psImageAlloc(NUM_COLS, NUM_ROWS, PS_TYPE_F32);
-    psS32 numPeaksOrig = 0;
-    for (psS32 i = 0 ; i < NUM_ROWS ; i++) {
-        for (psS32 j = 0 ; j < NUM_COLS ; j++) {
-            if ((0 == i%2) && (0 == j%2)) {
-                imgData->data.F32[i][j] = (float) (i + 10);
-                numPeaksOrig++;
-            } else {
-                imgData->data.F32[i][j] = 0.0;
-            }
-        }
-    }
-    // Call pmPeaksSubset() with large maxValue and disjoint psRegion.
-    // Should not remove any peaks.
-    {
-        psMemId id = psMemGetId();
-        psArray *outData = pmPeaksInImage(imgData, 0.0);
-        psArray *outData2 = pmPeaksSubset(outData, PS_MAX_F32, psRegionSet(20, 20, 20, 20));
-        ok(outData2 != NULL && psMemCheckArray(outData),
-           "pmPeaksSubset() returned a non-NULL psArray (large maxValue)");
-        ok(outData2->n == numPeaksOrig,
-          "pmPeaksSubset() returned correct number of peaks (was %d, should be %d)", outData2->n+1, numPeaksOrig);
-        psFree(outData);
-        psFree(outData2);
-        ok(!psMemCheckLeaks (id, NULL, NULL, false), "no memory leaks");
-    }
-
-
-    // Call pmPeaksSubset() with small maxValue and disjoint psRegion.
-    // Should not remove any peaks.
-    {
-        psMemId id = psMemGetId();
-        psArray *outData = pmPeaksInImage(imgData, 0.0);
-        psArray *outData2 = pmPeaksSubset(outData, 0.0, psRegionSet(20, 20, 20, 20));
-        ok(outData2 != NULL && psMemCheckArray(outData),
-           "pmPeaksSubset() returned a non-NULL psArray (small maxValue)");
-        ok(outData2->n == 0,
-          "pmPeaksSubset() returned correct number of peaks (was %d, should be %d)", outData2->n, 0);
-        psFree(outData);
-        psFree(outData2);
-        ok(!psMemCheckLeaks (id, NULL, NULL, false), "no memory leaks");
-    }
-
-
-    // Call pmPeaksSubset() with large maxValue and enclosing psRegion.
-    // Should remove aall peaks.
-    {
-        psMemId id = psMemGetId();
-        psArray *outData = pmPeaksInImage(imgData, 0.0);
-        psRegion tmpRegion = psRegionSet(-PS_MAX_F32, PS_MAX_F32, -PS_MAX_F32, PS_MAX_F32);
-        psArray *outData2 = pmPeaksSubset(outData, PS_MAX_F32, tmpRegion);
-        ok(outData2 != NULL && psMemCheckArray(outData),
-           "pmPeaksSubset() returned a non-NULL psArray (small maxValue, enclosing psRegion)");
-        ok(outData2->n == 0,
-          "pmPeaksSubset() returned correct number of peaks (was %d, should be %d)", outData2->n, 0);
-        psFree(outData);
-        psFree(outData2);
-        ok(!psMemCheckLeaks (id, NULL, NULL, false), "no memory leaks");
-    }
-
-
-    // Call pmPeaksSubset() with large maxValue and enclosing psRegion.
-    // Should remove aall peaks.
-    {
-        psMemId id = psMemGetId();
-        psArray *outData = pmPeaksInImage(imgData, 0.0);
-        psRegion tmpRegion = psRegionSet(-PS_MAX_F32, PS_MAX_F32, -PS_MAX_F32, PS_MAX_F32);
-        psArray *outData2 = pmPeaksSubset(outData, 0.0, tmpRegion);
-        ok(outData2 != NULL && psMemCheckArray(outData),
-           "pmPeaksSubset() returned a non-NULL psArray (small maxValue, inclusive psRegion)");
-        ok(outData2->n == 0,
-          "pmPeaksSubset() returned correct number of peaks (was %d, should be %d)", outData2->n, 0);
-        psFree(outData);
-        psFree(outData2);
-        ok(!psMemCheckLeaks (id, NULL, NULL, false), "no memory leaks");
-    }
 }
Index: trunk/psModules/test/objects/tap_pmSource.c
===================================================================
--- trunk/psModules/test/objects/tap_pmSource.c	(revision 29547)
+++ trunk/psModules/test/objects/tap_pmSource.c	(revision 31153)
@@ -21,5 +21,5 @@
         pmSourceCacheModel()
         pmSourceCachePSF()
-        pmSourceSortBySN()	(COMPILER ERRORS)
+        pmSourceSortByFlux()	(COMPILER ERRORS)
         pmSourceSortByY()	(COMPILER ERRORS)
     Must test
@@ -801,7 +801,7 @@
 
     // ----------------------------------------
     // pmSourceSortBySN() tests
     // int pmSourceSortBySN (const void **a, const void **b)
     // Call pmSourceSortBySN() with acceptable input parameters.
     // XXX: We don't test with NULL input parameters since this function has no PS_ASSERTS to protect
     // against that.
@@ -816,10 +816,10 @@
         src2->peak->SN = 20.0;
 
-        int rc = pmSourceSortBySN((const void **) &src1, (const void **) &src2);
-        ok(rc == 1, "pmSourceSortBySN() returned correct result (source1 < source2) (%d)", rc);
-        rc = pmSourceSortBySN((const void **) &src2, (const void **) &src1);
-        ok(rc == -1, "pmSourceSortBySN() returned correct result (source2 < source1) (%d)", rc);
-        rc = pmSourceSortBySN((const void **) &src1, (const void **) &src1);
-        ok(rc == 0, "pmSourceSortBySN() returned correct result (source1 == source2) (%d)", rc);
+        int rc = pmSourceSortByFlux((const void **) &src1, (const void **) &src2);
+        ok(rc == 1, "pmSourceSortByFlux() returned correct result (source1 < source2) (%d)", rc);
+        rc = pmSourceSortByFlux((const void **) &src2, (const void **) &src1);
+        ok(rc == -1, "pmSourceSortByFlux() returned correct result (source2 < source1) (%d)", rc);
+        rc = pmSourceSortByFlux((const void **) &src1, (const void **) &src1);
+        ok(rc == 0, "pmSourceSortByFlux() returned correct result (source1 == source2) (%d)", rc);
 
         psFree(src1);
@@ -801,7 +801,7 @@
 
     // ----------------------------------------
-    // pmSourceSortBySN() tests
-    // int pmSourceSortBySN (const void **a, const void **b)
-    // Call pmSourceSortBySN() with acceptable input parameters.
+    // pmSourceSortByFlux() tests
+    // int pmSourceSortByFlux (const void **a, const void **b)
+    // Call pmSourceSortByFlux() with acceptable input parameters.
     // XXX: We don't test with NULL input parameters since this function has no PS_ASSERTS to protect
     // against that.
